@@ -7,6 +7,8 @@ def get_arguments():
     )
     parser.add_argument("-w", "--work_time", help="Set the work time length", type=int)
     parser.add_argument(
-        "-b", "--break_time", help="Set the break time length", type=int
+        "-r", "--rest_time", help="Set the rest time length", type=int
     )
+    parser.add_argument("-d", '--double_speed', dest='double_speed', action='store_true')
+    parser.set_defaults(double_speed=False)
     return parser.parse_args()
